Installing Quizdrill

The current version of this file is availible at our wiki-page.

# Quizdrill/Install

OpenFacts, the Open Source Knowledge Database

< Quizdrill

## Dependencies

To run Quizdrill you need Python (tested with 2.4), PyGTK (tested with 2.8.6), Glade, gettext and EasyInstall.

If your operating system includes a package management, chances are you can use your standard packaging system to easily download and install the needed dependencies. This include variations of BSD and Linux, as well as Fink or DarwinPorts for Mac OS X. On Debian or Ubuntu for example you can run "`apt-get install python python-gtk2 python-glade2 gettext python-setuptools`" to install all the dependencies. Note however that the package names very between different distributions.

### Installing Dependencies under Windows

The easiest way is to use the All-in-One-PyGTK-Installer which installs PyGTK, Python and GTK+-Runtime (all are needed). If you prefer the PyGTK download page includes a description to install all the different libraries manually.After that install Glade: Download libglade-bin and extract it to "`<all-in-one-install-path>\gtk\bin`".

In addition download and install gettext and finally EasyInstall by downloading and running ez_setup.py. ez_setup.py is also delivered with Quizdrill so you can also just use that version.

## Installing Quizdrill

There is no need to install Quizdrill. If you have the dependencies installed, just the source distribution (e. g. quizdrill-0.2.0.tar.gz) extract it and start src/quizdrill.py (e. g. with "`python src/quizdrill.py`").

It can however be installed if you prefer that. Download the package for your Distribution (e. g. .deb or .rpm on Debian/Ubuntu or Redhat/Suse) if it exists. Otherwise, the easiest way is the standard distutils way "`python setup.py install`". To install it in your home directory use the option "`--home`" or for a different folder the "`--prefix`" option. For more details see the Installing Python Manual. EasyInstall which you have installed as one of the dependencies can install it, too. Download the egg-file and run e. g. "`easy_install quizdrill-0.2.0.egg`". Easy Install can also handle updates and download Quizdrill automatically. Read their documentation for details.

## Building Distribution Specific Packages / Installer

To use the standard packaging (or installer) for your system build it with:

       python setup.py bdist_win           for a Windows Installer (highly discouraged)
       python setup.py bdist_rpm           for a Linux RPM-Package
       fakeroot dpkg-buildpackage -b       for a Linux Debian-Package

and then install the package (or installer) the way you are used to for your OS.